%global srcname pylero

Name:           python-%{srcname}
Version:        0.1.0
Release:        1%{?dist}
Summary:        Python SDK for Polarion

License:        MIT
URL:            https://github.com/RedHatQE/pylero
Source:         %{url}/archive/%{version}/pylero-%{version}.tar.gz

BuildArch:      noarch

%global _description %{expand:
This is Pylero, the Python wrapper for the Polarion WSDL API. The Pylero
wrapper enables native python access to Polarion objects and functionality
using object oriented structure and functionality. This allows the devlopers to
use Pylero in a natural fashion without being concerned about the Polarion
details.

All Pylero objects inherit from BasePolarion. The objects used in the library
are all generated from the SOAP factory class, using the python-suds library.
The Pylero class attributes are generated dynamically as properties, based on
a mapping dict between the pylero naming convention and the Polarion attribute
names.

The use of properties allows the pylero object attributes to be virtual with no
need for syncing between them and the Polarion objects they are based on.

The Polarion WSDL API does not implement validation/verification of data passed
in, so the Pylero library takes care of this itself. All enums are validated
before being sent to the server and raise an error if not using a valid value.
A number of workflow implementations are also included, for example when
creating a Document, it automatically creates the Heading work item at the same
time.

Polarion Work Items are configured per installation, to give native workitem
objects (such as TestCase), the library connects to the Polarion server,
downloads the list of workitems and creates them.}

%description %_description

%package -n python3-%{srcname}
Summary:        %{summary}
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
# Require by test
BuildRequires:  python3-suds

%description -n python3-%{srcname} %_description

%prep
%autosetup -p1 -n %{srcname}-%{version}
# EL8 python3-suds provides with python3.6dist(suds-jurko)
sed -i -e 's/"suds"/"suds-jurko"/g' setup.py

%build
%py3_build

%install
%py3_install

%global _pylero_import_include %{expand:pylero.activity_comment pylero.activity
pylero.approval pylero.attachment pylero.baseline pylero.build_test_results
pylero.category pylero.change pylero.comment pylero.custom_field
pylero.enum_custom_field_type pylero.exceptions pylero.properties
pylero.property pylero.test_step pylero.tests_configuration pylero.user
pylero.wiki_page pylero.work_record}

# Skip check on CentOS Stream 8 as py3_check_import macro is not supported
%if !(0%{?centos} == 8)
%check
# If the Polarion server URL is not specified in config some libraries will
# fail to import, only test import on few modules don't depend on the URL
%py3_check_import %{_pylero_import_include}
%endif

%files -n python3-%{srcname}
%doc README.md
%license LICENSE
%{python3_sitelib}/%{srcname}-*.egg-info/
%{python3_sitelib}/%{srcname}/
%{_bindir}/pylero-cmd
%{_bindir}/pylero

%changelog
* Tue May 21 2024 Wayne Sun <gsun@redhat.com> 0.1.0-1
- Update to 0.1.0

* Tue Mar 05 2024 Wayne Sun <gsun@redhat.com> 0.0.9-1
- Update to 0.0.9

* Tue Mar 14 2023 Wayne Sun <gsun@redhat.com> 0.0.8-1
- Update to 0.0.8

* Thu Feb 23 2023 Wayne Sun <gsun@redhat.com> 0.0.7-1
- Update suds requirement in prep
- Update to 0.0.7

* Fri Feb 17 2023 Wayne Sun <gsun@redhat.com> 0.0.6-1
- Update to 0.0.6

* Wed Dec 21 2022 Wayne Sun <gsun@redhat.com> 0.0.5-1
- Update to 0.0.5

* Wed Dec 7 2022 Wayne Sun <gsun@redhat.com> 0.0.4-1
- Initial packaging
